/**
 * You may contact the author by email: peter.tribble@gmail.com
 *
 * ContentsFileTreeNode
 *
 * Represents a Node in a local file tree
 *
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import java.util.*;
import javax.swing.tree.*;
import java.io.*;

public class ContentsFileTreeNode extends DefaultMutableTreeNode {

    private boolean explored = false;
    private boolean isdirectory = false;
    private File file;

    public ContentsFileTreeNode(File file) {
	this.file = file;
	isdirectory = file.isDirectory();
	setUserObject(file);
    }

    public boolean getAllowsChildren() {
	return isdirectory;
    }

    public boolean isLeaf() {
	return !isdirectory;
    }

    public File getFile() {
	return file;
    }

    public boolean isExplored() {
	return explored;
    }

    public boolean isDirectory() {
	return isdirectory;
    }

    public String toString() {
	return file.getName();
    }

    public String getAbsolutePath() {
	return file.getAbsolutePath();
    }

    public void explore() {
	if (isdirectory && !explored) {
	    // filter out dot files
	    File[] children = file.listFiles(new FilenameFilter() {
		public boolean accept(File d, String n) {
		    return !n.startsWith(".");
		}
	    });

	    // sort into alphabetic order
	    Arrays.sort(children);

	    for (int i = 0; i < children.length; ++i) {
		add(new ContentsFileTreeNode(children[i]));
	    }

	    explored = true;
	}
    }

}
