/**
 * ContentsPackage - The files contained in a Solaris package
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import java.util.*;

public class ContentsPackage {

    private List <ContentsFileDetail> filelist;

    public ContentsPackage() {
	filelist = new ArrayList <ContentsFileDetail> ();
    }

    public void addFile(ContentsFileDetail cfd) {
	filelist.add(cfd);
    }

    public int numEntries() {
	return filelist.size();
    }

    public int numDirectories() {
	int i = 0;
	for (ContentsFileDetail cfd : filelist) {
	    if (cfd.isDirectory()) {
		i++;
	    }
	}
	return i;
    }

    /*
     * pkginfo -l reports "linked files" just for hard links
     */
    public int numHardLinks() {
	int i = 0;
	for (ContentsFileDetail cfd : filelist) {
	    if (cfd.ftype.equals("l")) {
		i++;
	    }
	}
	return i;
    }

    public int numSymLinks() {
	int i = 0;
	for (ContentsFileDetail cfd : filelist) {
	    if (cfd.ftype.equals("s")) {
		i++;
	    }
	}
	return i;
    }

    /*
     * Devices are files of type b or c
     */
    public int numDevices() {
	int i = 0;
	for (ContentsFileDetail cfd : filelist) {
	    if (cfd.ftype.equals("c") || cfd.ftype.equals("b")) {
		i++;
	    }
	}
	return i;
    }

    /*
     * Shared files - contained in more than one package
     */
    public int numShared() {
	int i = 0;
	for (ContentsFileDetail cfd : filelist) {
	    if (cfd.isShared()) {
		i++;
	    }
	}
	return i;
    }

    /*
     * Add up the space used
     */
    public long spaceUsed() {
	long l = 0;
	for (ContentsFileDetail cfd : filelist) {
	    if (cfd.isRegular()) {
		l += Long.parseLong(cfd.size);
	    }
	}
	return l;
    }

    public List <ContentsFileDetail> getDetails() {
	return filelist;
    }
}
