/**
 * PackageInformationPanel
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import javax.swing.*;
import java.awt.*;
import uk.co.petertribble.jingle.JingleTextPane;

/**
 * Show information about installed files or packages in a set of
 * tabbed panels.
 */
public class PackageInformationPanel extends JTabbedPane {

    private JingleTextPane tp_info;
    private JingleTextPane tp_dep;
    private JingleTextPane tp_rdep;
    private JingleTextPane tp_cl;
    private JingleTextPane tp_files;
    private JScrollPane jfsp = null;
    private boolean showfiles = false;
    private boolean showdsp = false;

    private PkgResources pkgres;

    /**
     * Create a default PackageInformationPanel showing the information,
     * dependencies, and clusters tabs.
     */
    public PackageInformationPanel() {
	this(true, true, true, false, false);
    }

    /**
     * Create a PackageInformationPanel showing the specified tabs.
     */
    public PackageInformationPanel(boolean showinfo,
				   boolean showdependencies,
				   boolean showclusters,
				   boolean showfiles,
				   boolean showdependants) {
	this.showfiles = showfiles;

	pkgres = PkgResources.getInstance();

	tp_info = new JingleTextPane();
	tp_dep = new JingleTextPane();
	tp_rdep = new JingleTextPane();
	tp_cl = new JingleTextPane();
	tp_files = new JingleTextPane();
	if (showinfo) {
	    add(pkgres.getString("PKG.INFO"), new JScrollPane(tp_info));
	}
	if (showdependencies) {
	    add(pkgres.getString("PKG.DEPENDENCIES"), new JScrollPane(tp_dep));
	}
	if (showclusters) {
	    add(pkgres.getString("PKG.CLUSTERS"), new JScrollPane(tp_cl));
	}
	if (showfiles) {
	    add(pkgres.getString("PKG.FILES"), new JScrollPane(tp_files));
	}
	if (showdependants) {
	    add(pkgres.getString("PKG.DEPENDANTS"), new JScrollPane(tp_rdep));
	}
    }

    public void setInfoText(String si) {
	setInfoText(si, "", "");
    }

    public void setInfoText(String si, String sd) {
	setInfoText(si, sd, "");
    }

    public void setInfoText(String si, String sd, String srd) {
	updateText(tp_info, si);
	updateText(tp_dep, sd);
	updateText(tp_rdep, srd);
    }

    public void setClusterText(String s) {
	updateText(tp_cl, s);
    }

    public void setFilesText(String s) {
	if (s == null) {
	    hideFiles();
	} else {
	    if (!showfiles) {
		showFiles();
	    }
	    updateText(tp_files, s);
	}
    }

    private void updateText(JingleTextPane tp, String s) {
	tp.setText(s);
    }

    /**
     * Show the reverse dependency tab. If showing the selection panel,
     * the reverse dependency tab is inserted before it.
     */
    public void showRevDependencies() {
	if (showdsp) {
	    insertTab(pkgres.getString("PKG.DEPENDANTS"), (Icon) null,
		new JScrollPane(tp_rdep), (String) null, getTabCount()-2);
	} else {
	    add(pkgres.getString("PKG.DEPENDANTS"), new JScrollPane(tp_rdep));
	}
    }

    /**
     * Show the files tab. If showing the selection panel,
     * the files tab is inserted before it.
     */
    public void showFiles() {
	jfsp = new JScrollPane(tp_files);
	if (showdsp) {
	    insertTab(pkgres.getString("PKG.FILES"), (Icon) null,
		jfsp, (String) null, getTabCount()-2);
	} else {
	    add(pkgres.getString("PKG.FILES"), jfsp);
	}
	showfiles = true;
    }

    /**
     * Hide the files tab.
     */
    public void hideFiles() {
	if (showfiles) {
	    int ifiles = indexOfComponent(jfsp);
	    removeTabAt(ifiles);
	    showfiles = false;
	}
    }

    /**
     * Show a selection tab, which must be supplied.
     */
    public void showDsp(String s, DistributionSelectionPanel dsp) {
	add(s, dsp);
	showdsp = true;
    }
}
