/**
 * PackageTableModel
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import java.util.*;
import javax.swing.table.*;

public class PackageTableModel extends AbstractTableModel {

    private boolean showselected;

    private List <SolarisPackage> pkgs;

    /*
     * This class would be much easier if the optional checkbox were put
     * on the right rather than the left. As it is, we need to know whether
     * to show it and if we do we need to shift the columns along by one.
     */

    /*
     * Columns to show
     */
    private String[] col1 = { "Name", "Category", "Description" };
    private String[] col2 = { "Selected", "Name", "Category", "Description" };
    private String[] columnNames;

    public PackageTableModel(PkgList plist) {
	this(plist, false);
    }

    public PackageTableModel(PkgList plist, boolean showselected) {
	this.showselected = showselected;
	pkgs = plist.getPackages();
	if (showselected) {
	    columnNames = col2;
	} else {
	    columnNames = col1;
	}
    }

    public int getColumnCount() {
	return columnNames.length;
    }

    public int getRowCount() {
	return pkgs.size();
    }

    @Override
    public String getColumnName(int col) {
	return columnNames[col];
    }

    /**
     * return the appropriate data
     */
    public Object getValueAt(int row, int col) {
	SolarisPackage pkg = pkgs.get(row);
	if (showselected) {
	    if (col == 0) {
		return Boolean.valueOf(pkg.getSelected());
	    } else if (col == 1) {
		return pkg.getName();
	    } else if (col == 2) {
		String s =  pkg.getInfoItem("CATEGORY");
		if (s == null) {
		    return "";
		}
		String sc[] = s.split(",");
		return sc[0];
	    } else {
		return pkg.getDescription();
	    }
	} else {
	    if (col == 0) {
		return pkg.getName();
	    } else if (col == 1) {
		String s =  pkg.getInfoItem("CATEGORY");
		if (s == null) {
		    return "";
		}
		String sc[] = s.split(",");
		return sc[0];
	    } else {
		return pkg.getDescription();
	    }
	}
    }

    @Override
    public Class getColumnClass(int col) {
	if (showselected && (col == 0)) {
	    return Boolean.class;
	}
	return String.class;
    }

    /*
     * The only editable cells are those in the first column and only then
     * if we're showing the selection. Furthermore, if the package cannot
     * be unselected then it shouldn't be editable ether.
     *
     * FIXME re-enable; it's been disabled because there's nothing that
     * connects the selection to the profile
     */
    @Override
    public boolean isCellEditable(int row, int col) {
	// if (showselected && (col == 0)) {
	// return !getPackageAtRow(row).mustBeSelected();
	// }
	return false;
    }

    /*
     * Don't need to implement this method unless your table's
     * data can change.
     */
    @Override
    public void setValueAt(Object value, int row, int col) {
	if (showselected && (col == 0)) {
	    Boolean b = (Boolean) value;
	    getPackageAtRow(row).setSelected(b.booleanValue());
	    fireTableCellUpdated(row, col);
	}
    }

    public SolarisPackage getPackageAtRow(int irow) {
	return pkgs.get(irow);
    }
}
