package uk.co.petertribble.pkgview;

import java.util.Comparator;

/**
 * Sorts Solaris patch numbers. These are of the form ######-##
 * comprising a 6-digit patch number and a 2-digit revision. The
 * patch number is first compared, the revision is only compared
 * if the patch number is the same.
 *
 * @author Peter C. Tribble
 */

public class PatchComparator implements Comparator <SolarisPatch> {
    private static final PatchComparator INSTANCE =
	    new PatchComparator();

    private
    PatchComparator()
    {
    }

    public static PatchComparator
    getInstance()
    {
	return INSTANCE;
    }

    public int
    compare(SolarisPatch p1, SolarisPatch p2)
    {
	int lp1 = p1.getId();
	int lp2 = p2.getId();
	if (lp1 != lp2) {
	    return (lp1 - lp2);
	}
	return (p1.getRevision() - p2.getRevision());
    }
}
