/**
 * SmfTree - shows SMF services in a tree
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview;

import javax.swing.*;
import javax.swing.tree.*;
import java.util.*;

public class SmfTree extends JTree {

    private SmfUtils smfutil;

    private Map <String, SmfTreeNode> treeMap;

    /**
     * Display a tree of SMF services
     */
    public SmfTree(String title) {
	this(new SmfUtils(), title);
    }

    /**
     * Display a tree of SMF services
     */
    public SmfTree(SmfUtils smfutil, String title) {
	this.smfutil = smfutil;

	treeMap = new HashMap <String, SmfTreeNode> ();

	DefaultMutableTreeNode root = new DefaultMutableTreeNode(title);
	buildTree(root);

	setModel(new DefaultTreeModel(root));
    }

    public String getStatus(String smf) {
	return smfutil.getStatus(smf);
    }

    public String getLog(String smf) {
	return smfutil.getLog(smf);
    }

    public String getHtmlInfo(String smf) {
	return smfutil.getHtmlInfo(smf);
    }

    public SmfService getService(String smf) {
	return smfutil.getService(smf);
    }

    private void buildTree(DefaultMutableTreeNode root) {
	for (String s : smfutil.getServices()) {
	    addService(s, root);
	}
    }

    private void addService(String s, DefaultMutableTreeNode root) {
	/*
	 * We first break up the String into its components and then walk
	 * through them. The last component is the leaf node.
	 *
	 * We store the node for each path in a Hash, and check for that.
	 */
	StringBuilder sb = new StringBuilder();
	String[] parts = s.split("[:/]+");
	// first one is special
	sb.append(parts[0]).append(":");
	SmfTreeNode stn = treeMap.get(sb.toString());
	if (stn == null) {
	    stn = new SmfTreeNode(sb.toString(), parts[0]);
	    treeMap.put(sb.toString(), stn);
	    root.add(stn);
	}
	for (int i = 1; i < parts.length-1; i++) {
	    sb.append("/").append(parts[i]);
	    SmfTreeNode stn2 = treeMap.get(sb.toString());
	    if (stn2 == null) {
		stn2 = new SmfTreeNode(sb.toString(), parts[i]);
		treeMap.put(sb.toString(), stn2);
		stn.add(stn2);
	    }
	    stn = stn2;
	}
	// the last is special too
	stn.add(new SmfTreeNode(s, parts[parts.length-1]));
    }

}
