/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.solview.explorer;

import uk.co.petertribble.jkstat.api.*;
import uk.co.petertribble.jkstat.gui.KstatAccessoryPanel;
import uk.co.petertribble.jingle.SpringUtilities;
import javax.swing.*;
import java.text.DecimalFormat;

public class AccessoryKmemAlloc extends KstatAccessoryPanel {

    private DecimalFormat df;

    private JProgressBar jpAlloc;
    private JProgressBar jpFree;

    private long iomax = 100;
    private long numalloc;
    private long numfree;
    private long nnumalloc;
    private long nnumfree;

    /**
     * Create a panel showing the input and output traffic on the
     * given kstat that updates every interval seconds.
     */
    public AccessoryKmemAlloc(String module, int instance, String name,
			int interval, JKstat jkstat) {
	super(module, instance, name, interval, jkstat);

	df = new DecimalFormat("##0.0#");

	// the progress meters are measured in kbytes/s
	jpAlloc = new JProgressBar(0, (int) iomax);
	jpFree = new JProgressBar(0, (int) iomax);
	// these will be rescaled later if need be

	jpAlloc.setStringPainted(true);
	jpFree.setStringPainted(true);

	SpringLayout layout = new SpringLayout();
	setLayout(layout);

	add(new JLabel(name + " alloc/s"));
	add(jpAlloc);
	add(new JLabel("free/s"));
	add(jpFree);
	SpringUtilities.makeCompactGrid(this, 1, 4, 6, 3, 2, 2);

	// read the counters once
	updateKstat();
	numalloc = ks.longData("alloc");
	numfree = ks.longData("free");
	updateAccessory();

	// kick a timer into life
	startLoop();
    }

    @Override
    public void updateAccessory() {
	updateKstat();
	nnumalloc = ks.longData("alloc");
	nnumfree = ks.longData("free");
	int i = (int) ((nnumalloc-numalloc)*1000000000/snapdelta);
	int j = (int) ((nnumfree-numfree)*1000000000/snapdelta);
	while ((i > iomax) || (j > iomax)) {
	    iomax = iomax*2;
	    jpAlloc.setMaximum((int) iomax);
	    jpFree.setMaximum((int) iomax);
	}
	jpAlloc.setValue(i);
	jpAlloc.setString(df.format(i));
	jpFree.setValue(j);
	jpFree.setString(df.format(j));
	numalloc = nnumalloc;
	numfree = nnumfree;
    }

}
