/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import java.awt.BorderLayout;
import uk.co.petertribble.jkstat.api.*;
import uk.co.petertribble.jingle.TableSorter;
import java.util.Set;
import java.util.Vector;

public class JFSstatPanel extends JPanel {

    private FsstatTableModel ftm;

    // all fsstat kstats have names starting vopstats_
    private static final String vop_prefix = "vopstats_";

    public JFSstatPanel(JKstat jkstat, int interval) {
	setLayout(new BorderLayout());

	// FsstatTableModel requires a Vector
	Vector <Kstat> vkstat = new Vector <Kstat> ();

	/*
	 * All fsstat kstats are under unix:0
	 */
	KstatFilter ksf = new KstatFilter(jkstat);
	ksf.addFilter("unix:0::");

	for (Kstat ks : ksf.getKstats()) {
	    if (ks.getName().startsWith(vop_prefix)) {
		vkstat.add(ks);
	    }
	}

	ftm = new FsstatTableModel(vkstat, interval, jkstat);
	TableSorter sortedModel = new TableSorter(ftm);
	JTable sftmtable = new JTable(sortedModel);
	add(new JScrollPane(sftmtable));
	sortedModel.setTableHeader(sftmtable.getTableHeader());
    }

    public void setNames(String s) {
	ftm.setNames(s);
    }

    public void stopLoop() {
	ftm.stopLoop();
    }

    public void setDelay(int i) {
	ftm.setDelay(i);
    }

    public String getCurrentTitle() {
	return ftm.getCurrentTitle();
    }

    public Set <String> getTitles() {
	return ftm.getTitles();
    }

}
