/**
 * MemoryInfoPanel - shows Memory status
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import uk.co.petertribble.jkstat.api.*;
import uk.co.petertribble.solview.InfoCommand;
import uk.co.petertribble.jingle.JingleTextPane;

public class MemoryInfoPanel extends InfoPanel {

    private JingleTextPane tp;
    private JKstat jkstat;
    private JKmemPanel kmPanel;
    private ArcStatPanel arcPanel;

    /**
     * Display a Memory information panel.
     */
    public MemoryInfoPanel(SysItem hi, JKstat jkstat) {
	super(hi);
	this.jkstat = jkstat;

	tp = new JingleTextPane("text/plain");

	display();
	validate();
    }

    public void stopLoop() {
	if (kmPanel != null) {
	    kmPanel.stopLoop();
	}
	if (arcPanel != null) {
	    arcPanel.stopLoop();
	}
    }

    /*
     * Display an information panel appropriate to the Memory item that is
     * selected.
     */
    private void display() {
	switch (hi.getType()) {
	    case SysItem.MEM_ARCSTAT:
		displayArc();
		break;
	    case SysItem.MEM_KMEM:
		displayKmem();
		break;
	    case SysItem.MEM_CONTAINER:
		displaySummary();
		break;
	}
    }

    /*
     * Top level summary. just swap
     */
    private void displaySummary() {
	jvp.add(new JLabel("Memory Summary"));
	InfoCommand ic = new InfoCommand("swap", "/usr/sbin/swap", "-l");
	tp.setText(ic.getOutput());
	jvp.add(new JScrollPane(tp));
    }

    /*
     * ZFS arc stats
     */
    private void displayArc() {
	jvp.add(new JLabel("ZFS ARC statistics"));
	arcPanel = new ArcStatPanel(jkstat, 5);
	jvp.add(new JScrollPane(arcPanel));
    }

    /*
     * kmem allocation statistics
     */
    private void displayKmem() {
	jvp.add(new JLabel("Kernel memory allocation"));
	kmPanel = new JKmemPanel(jkstat, 5);
	jvp.add(new JScrollPane(kmPanel));
    }
}
