/**
 * SysInfoPanel - shows Sys status
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import java.awt.BorderLayout;
import uk.co.petertribble.jkstat.api.JKstat;
import uk.co.petertribble.jingle.JingleTextPane;

public class SysInfoPanel extends JPanel {

    private InfoPanel ip = null;
    private JingleTextPane tp;
    private JTabbedPane jtp;
    private JKstat jkstat;

    /**
     * Display an Sys information panel
     */
    public SysInfoPanel(JKstat jkstat) {
	this.jkstat = jkstat;
	setLayout(new BorderLayout());
	jtp = new JTabbedPane();
	add(jtp);

	tp = new JingleTextPane();
	jtp.add("Status", new JScrollPane(tp));
    }

    /**
     * Display an information panel appropriate to the hardware item that is
     * selected. Stops and removes any previous panel that may have been
     * displayed.
     */
    public void display(SysItem hi) {
	if (ip != null) {
	    ip.stopLoop();
	}
	removeAll();
	validate();
	/*
	 * FIXME need a JingleVPanel at some point to get the alignment right
	 */
	switch (hi.getType()) {
	    case SysItem.CPU_CONTAINER:
	    case SysItem.CPU:
	    case SysItem.CPU_CORE:
	    case SysItem.CPU_THREAD:
		ip = new CpuInfoPanel(hi, jkstat);
		add(ip);
		break;
	    case SysItem.DISK_CONTAINER:
	    case SysItem.DISK:
	    case SysItem.DISK_PARTITION:
	    case SysItem.DISK_METADEVICE:
	    case SysItem.DISK_META_CONTAINER:
		ip = new DiskInfoPanel(hi, jkstat);
		add(ip);
		break;
	    case SysItem.NET_CONTAINER:
	    case SysItem.NET_INTERFACE:
	    case SysItem.NET_PROTOCOL:
	    case SysItem.NET_PROTO_IP:
	    case SysItem.NET_PROTO_TCP:
	    case SysItem.NET_PROTO_UDP:
		ip = new NetInfoPanel(hi, jkstat);
		add(ip);
		break;
	    case SysItem.MEM_CONTAINER:
	    case SysItem.MEM_KMEM:
	    case SysItem.MEM_ARCSTAT:
		ip = new MemoryInfoPanel(hi, jkstat);
		add(ip);
		break;
	    case SysItem.FS_FSSTAT:
	    case SysItem.FS_CONTAINER:
	    case SysItem.ZFS_CONTAINER:
	    case SysItem.ZFS_FS:
		ip = new FsInfoPanel(hi, jkstat);
		add(ip);
		break;
	    default:
		add(jtp);
		tp.setText(hi.toString());
	}
	validate();
    }
}
